#ifndef __API_H__
#define __API_H__

int PlatformInit(void);
int InitSelConfig(void);
int InitSdrConfig(void);
int Init_IPMI_FRU_SDR_SEL(void);
int Init_SessionTbl(void);
int InitTimerTaskTbl(void);

int UpdateFlash(void);
int SetSysTime(uint32_t *timeSecond);
int GetSysTime(void);
#define SET_SYSTEM_TIME_STAMP(time) SetSysTime(time)
#define GET_SYSTEM_TIME_STAMP GetSysTime

int PostEventMessage (uint8_t *EventMsg,uint8_t size);

extern uint8_t PDK_GetSlotID(void);
extern uint8_t PDK_GetChassisID(void);
extern int PDK_PowerOffChassis(void);
extern int PDK_PowerOnChassis(void);
extern int PDK_SoftOffChassis(void);
extern int PDK_PowerCycleChassis(void);
extern int PDK_ResetChassis(void);
extern int PDK_DiagInterruptChassis(void);
extern int PDK_FanControl(void);

char* getip(char *ip_buf);
int setip(char *ip);
char* getmac(char *mac_buf);

#endif /* __API_H__ */